@@ -15,7 +15,7 @@ from optparse import OptionParser
 from .plugins import HairballPlugin
 
 
-__version__ = '0.2'
+__version__ = '0.3'
 
 
 class KurtCache(object):
@@ -67,8 +67,14 @@ class KurtCache(object):
         path = self.key_to_path(key)
         # Return the cached file if available
         if key in self.hashes:
-            with open(path) as fp:
-                return cPickle.load(fp)
+            try:
+                with open(path) as fp:
+                    return cPickle.load(fp)
+            except EOFError:
+                os.unlink(path)
+                self.hashes.remove(key)
+            except IOError:
+                self.hashes.remove(key)
         # Create the nested cache directory
         try:
             os.makedirs(os.path.dirname(path))
