@@ -12,16 +12,16 @@ class Animation(HairballPlugin):
 
     """
 
-    COSTUME = frozenset(['switch to costume %l', 'next costume'])
-    LOOP = frozenset(['repeat %n', 'repeat until %b', 'forever',
-                      'forever if %b'])
-    MOTION = frozenset(['change y by %n', 'change x by %n',
-                        'glide %n secs to x:%n y:%n',
-                        'move %n steps', 'go to x:%n y:%n'])
-    ROTATE = frozenset(['turn cw %n degrees', 'turn ccw %n degrees',
-                        'point in direction %d'])
-    SIZE = frozenset(['change size by %n', 'set size to %n%'])
-    TIMING = frozenset(['wait %n secs', 'glide %n secs to x:%n y:%n'])
+    COSTUME = frozenset(['switch to costume %s', 'next costume'])
+    LOOP = frozenset(['repeat %s', 'repeat until %s%s', 'forever',
+                      'forever if %s%s'])
+    MOTION = frozenset(['change y by %s', 'change x by %s',
+                        'glide %s secs to x:%s y:%s',
+                        'move %s steps', 'go to x:%s y:%s'])
+    ROTATE = frozenset(['turn cw %s degrees', 'turn ccw %s degrees',
+                        'point in direction %s'])
+    SIZE = frozenset(['change size by %s', 'set size to %s%%'])
+    TIMING = frozenset(['wait %s secs', 'glide %s secs to x:%s y:%s'])
     ANIMATION = COSTUME | LOOP | MOTION | ROTATE | SIZE | TIMING
 
     @staticmethod
@@ -61,7 +61,8 @@ class Animation(HairballPlugin):
                 return 0
         return -1
 
-    def check_animation(self, last, last_level, gen):
+    def _check_animation(self, last, last_level, gen):
+        """Internal helper function to check the animation."""
         tmp_ = Counter()
         results = Counter()
         name, level, block = last, last_level, last
@@ -88,7 +89,7 @@ class Animation(HairballPlugin):
             # allow some exceptions
             if name not in self.ANIMATION and name != '':
                 if not others:
-                    if block.type.flag != 't':
+                    if block.type.shape != 'stack':
                         last_level = level
                         (name, level, block) = next(gen, ('', 0, ''))
                         others = True
@@ -97,7 +98,8 @@ class Animation(HairballPlugin):
             results[count] += 1
         return gen, results
 
-    def analyze(self, scratch):
+    def analyze(self, scratch, **kwargs):
+        """Run and return the results from the Animation plugin."""
         results = Counter()
         for script in self.iter_scripts(scratch):
             gen = self.iter_blocks(script.blocks)
@@ -105,7 +107,7 @@ class Animation(HairballPlugin):
             level = None
             while name != '':
                 if name in self.ANIMATION:
-                    gen, count = self.check_animation(name, level, gen)
+                    gen, count = self._check_animation(name, level, gen)
                     results.update(count)
                 name, level, _ = next(gen, ('', 0, ''))
         return {'animation': results}
@@ -124,7 +126,8 @@ class BroadcastReceive(HairballPlugin):
                 events[event].add(script)
         return events
 
-    def analyze(self, scratch):
+    def analyze(self, scratch, **kwargs):
+        """Run and return the results from the BroadcastReceive plugin."""
         all_scripts = list(self.iter_scripts(scratch))
         results = defaultdict(set)
         broadcast = dict((x, self.get_broadcast_events(x))  # Events by script
@@ -163,9 +166,10 @@ class BroadcastReceive(HairballPlugin):
             if len(scripts) > 1:
                 for script in scripts:
                     for _, _, block in self.iter_blocks(script.blocks):
-                        if block.type.flag == 't':
+                        if block.type.shape == 'stack':
                             results['multiple receivers with delay'].add(event)
-                            del correct[event]
+                            if event in correct:
+                                del correct[event]
 
         results['success'] = set(correct.keys())
         return {'broadcast': results}
@@ -188,7 +192,7 @@ class SaySoundSync(HairballPlugin):
     HACKISH = 2
 
     SAY_THINK = ('say %s', 'think %s')
-    SAY_THINK_DURATION = ('say %s for %n secs', 'think %s for %n secs')
+    SAY_THINK_DURATION = ('say %s for %s secs', 'think %s for %s secs')
     ALL_SAY_THINK = SAY_THINK + SAY_THINK_DURATION
 
     @staticmethod
@@ -196,7 +200,7 @@ class SaySoundSync(HairballPlugin):
         """Return True if the string is empty, or only whitespace."""
         return not word or word.isspace()
 
-    def analyze(self, scratch):
+    def analyze(self, scratch, **kwargs):
         """Categorize instances of attempted say and sound synchronization."""
         errors = Counter()
         for script in self.iter_scripts(scratch):
@@ -205,14 +209,14 @@ class SaySoundSync(HairballPlugin):
             for name, depth, block in gen:
                 if prev_depth == depth:
                     if prev_name in self.SAY_THINK:
-                        if name == 'play sound %S until done':
+                        if name == 'play sound %s until done':
                             if not self.is_blank(prev_block.args[0]):
                                 errors += self.check(gen)
                         # TODO: What about play sound?
                     elif prev_name in self.SAY_THINK_DURATION and \
-                            'play sound %S' in name:
+                            'play sound %s' in name:
                         errors['1'] += 1
-                    elif prev_name == 'play sound %S':
+                    elif prev_name == 'play sound %s':
                         if name in self.SAY_THINK:
                             errors[self.INCORRECT] += 1
                         elif name in self.SAY_THINK_DURATION:
@@ -220,7 +224,7 @@ class SaySoundSync(HairballPlugin):
                                 errors[self.ERROR] += 1
                             else:
                                 errors[self.HACKISH] += 1
-                    elif prev_name == 'play sound %S until done' and \
+                    elif prev_name == 'play sound %s until done' and \
                             name in self.ALL_SAY_THINK:
                         if not self.is_blank(block.args[0]):
                             errors[self.INCORRECT] += 1
@@ -248,7 +252,7 @@ class SaySoundSync(HairballPlugin):
                 retval[self.CORRECT] += 1
             else:
                 name, _, block = next(gen, ('', 0, ''))
-                if name == 'play sound %S until done':
+                if name == 'play sound %s until done':
                     # Increment the correct count because we have at least
                     # one successful instance
                     retval[self.CORRECT] += 1
